package com.lantone.qc.kernel.catalogue.clinicalblood;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.ClinicalBloodDoc;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @ClassName : CLI0568
 * @Description :  输血记录输血记录时间未填写
 * @Author : 楼辉荣
 * @Date: 2020-03-06 17:28
 */
@Component
public class CLI0568 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        List<ClinicalBloodDoc> clinicalBloodDocs = inputInfo.getClinicalBloodDocs();
        if(clinicalBloodDocs != null && clinicalBloodDocs.size()>0){
            for (ClinicalBloodDoc cliB:clinicalBloodDocs) {
                Map<String, String> cliBStructureMap = cliB.getStructureMap();
                String key = getKeyByHospitalId();
                if(cliBStructureMap.containsKey(key)){
                    if(StringUtils.isEmpty(cliBStructureMap.get(key))){
                        status.set("-1");
                        break;
                    }
                }else {
                    status.set("-1");
                    break;
                }

            }
        }

    }
    private String getKeyByHospitalId() {
        switch (Content.hospital_Id)
        {
            case "7":               //厦门
                return "病历日期";
            default:
                return "记录时间";
        }
    }
}