package com.lantone.qc.kernel.catalogue.firstcourserecord;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.FirstCourseRecordDoc;
import com.lantone.qc.pub.model.label.CaseCharacteristicLabel;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @ClassName : FIRC0085
 * @Description : 未归纳出病史特点
 * @Author : rengb
 * @Date: 2020-03-06 17:28
 */
@Component
public class FIRC03152 extends QCCatalogue {

    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        boolean medicalHistory=false;
        boolean physicalCheck=false;
        boolean auxiliaryExamination=false;
        FirstCourseRecordDoc firstCourseRecordDoc = inputInfo.getFirstCourseRecordDoc();
        if(firstCourseRecordDoc==null){
            return;
        }
        List<String> physicalCheckList = Content.physicalCheckList;
        List<String> auxiliaryExaminationList = Content.auxiliaryExaminationList;
        List<String> medicalHistoryList = Content.medicalHistoryList;
        List<String> physicalCheckBTList = Content.physicalCheckBTList;
        Map<String, String> structureMap = firstCourseRecordDoc.getStructureMap();
        String characteristics  = structureMap.get("病例特点");
        //去结构化数据种找
        if(StringUtil.isNotBlank(characteristics)){
            for (String medicalHistoryStr : medicalHistoryList) {
                if(characteristics.contains(medicalHistoryStr)){
                    medicalHistory=true;
                }
            }
            for (String physicalCheckStr: physicalCheckList) {
                if(characteristics.contains(physicalCheckStr)){
                    physicalCheck=true;
                }
            }

            for (String auxiliaryExaminationStr: auxiliaryExaminationList) {
                if(characteristics.contains(auxiliaryExaminationStr)){
                    auxiliaryExamination=true;
                }
            }
        }
        for (String medicalHistoryStr : medicalHistoryList) {
            if(StringUtil.isNotEmpty(structureMap.get(medicalHistoryStr))){
                medicalHistory=true;
            }
        }
        for (String physicalCheckBT : physicalCheckBTList) {
            if(StringUtil.isNotEmpty(structureMap.get(physicalCheckBT))){
                physicalCheck=true;
            }
        }
        for (String auxiliaryExaminationStr: auxiliaryExaminationList) {
            if(StringUtil.isNotEmpty(structureMap.get(auxiliaryExaminationStr))){
                auxiliaryExamination=true;
            }
        }
        if(!medicalHistory&&!physicalCheck&&!auxiliaryExamination){
            return;
        }
        if(!medicalHistory||!physicalCheck||!auxiliaryExamination){
            status.set("-1");
            return;
        }
    }
}