package com.lantone.qc.kernel.catalogue.hospital.beilun.firstpagerecord;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.BeHospitalizedDoc;
import com.lantone.qc.pub.model.entity.AllergyMedicine;
import com.lantone.qc.pub.model.label.PastLabel;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @ClassName : FIRP0184
 * @Description :药物过敏史未填写
 * @Author : 胡敬
 * @Date: 2020-03-16 20:18
 */
@Component
public class FIRP0184 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        BeHospitalizedDoc beHospitalizedDoc = inputInfo.getBeHospitalizedDoc();
        if (inputInfo.getFirstPageRecordDoc() == null || beHospitalizedDoc == null) {
            return;
        }
        Map<String, String> firstpageStructureMap = inputInfo.getFirstPageRecordDoc().getStructureMap();
        PastLabel pastLabel = beHospitalizedDoc.getPastLabel();
        if (pastLabel == null) {
            return;
        }
        List<AllergyMedicine> allergyMedicines = pastLabel.getAllergyMedicines();
        if (allergyMedicines == null) {
            return;
        }

        long count = allergyMedicines.stream().filter(allergyMedicine -> {
            boolean flag = false;
            if (allergyMedicine.getNegative() == null
                    && StringUtil.isNotBlank(allergyMedicine.getName())) {
                flag = true;
            }
            return flag;
        }).count();

        if (count > 0 && firstpageStructureMap != null) {
            String drugAllergy = firstpageStructureMap.get(Content.drugAllergy);
            if (CatalogueUtil.isEmpty(drugAllergy)) {
                status.set("-1");
                return;
            }
        }
    }
}