package com.lantone.qc.kernel.catalogue.hospital.beilun.firstpagerecord;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.google.gson.JsonObject;
import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.AnesthesiaRecordDoc;
import com.lantone.qc.pub.model.doc.FirstPageRecordDoc;
import com.lantone.qc.pub.model.doc.operation.OperationDoc;
import com.lantone.qc.pub.util.DateUtil;
import com.lantone.qc.pub.util.StringUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;
import java.util.regex.Pattern;


/**
 * @ClassName: FIRP03104
 * @Description: 麻醉医师与麻醉记录不一致
 * @Author songxl
 * @Date 2021/3/19
 * @Version 1.0
 */
@Component
@Slf4j
public class FIRP03104 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        /**
         * 获取手术记录和麻醉记录麻醉医师 判断麻醉医师是否相同
         */
        status.set("0");
        //1.获取患者的病案首页相关文档,手麻记录
        FirstPageRecordDoc firstPageRecordDoc = inputInfo.getFirstPageRecordDoc();
        if(firstPageRecordDoc==null||firstPageRecordDoc.getStructureExtMap().isEmpty()
            ||firstPageRecordDoc.getStructureExtMap().get("手术信息")==null
        ||(JSONArray.parseArray(""+firstPageRecordDoc.getStructureExtMap().get("手术信息"))).isEmpty())//无病案首页相关记录或者病案首页无手术记录
        {
            return;
        }
        List<AnesthesiaRecordDoc> anesthesiaDocs  = inputInfo.getAnesthesiaRecordDocs();
        if(anesthesiaDocs==null|| anesthesiaDocs.isEmpty())//无手麻相关记录
        {
            return;
        }
        //2.获取手术信息
       try{
           JSONArray  operationArr = JSONArray.parseArray(""+firstPageRecordDoc.getStructureExtMap().get("手术信息"));
           for(Object operationOBJ:operationArr)
           {
               JSONObject operationJson = JSONObject.parseObject(operationOBJ+"");
                  if(operationJson!=null)
                  {
                      //2.1获取手术麻醉医师
                      String anesthesiaDoctor = operationJson.getString("麻醉医师");
                      //通过手术时间判断是否是同一个手术
                      Date operationStartTime = DateUtil.newParseDateTime(operationJson.getString("手术日期"));
                      if(StringUtil.isBlank(anesthesiaDoctor)) {
                          status.set("-1");
                          return;
                      }
                      if(operationStartTime ==null) {continue;}
                      anesthesiaDocs.forEach(anesthesiaRecordDoc -> {
                          //2.2遍历手麻记录，对比手术名称(如果手麻开始时间和病案首页记录时间在3个小时以内则判定为同一台手术)
                          if (CatalogueUtil.compareTime(operationStartTime,
                                  anesthesiaRecordDoc.getAnesStartTime(),
                                  Long.valueOf(2 * 60)))
                          {
                              if(StringUtil.isNotBlank(anesthesiaRecordDoc.getAnesthesiaDoctor()))
                              {
                                  if(!StringUtil.equals(anesthesiaDoctor,anesthesiaRecordDoc.getAnesthesiaDoctor()))
                                  {
                                      status.set("-1");
                                      return;
                                  }
                              }
                          }

                      });
                  }
           }
       }
       catch (Exception e)
       {
           log.error(e.getMessage(),e);
       }

    }
}
