package com.lantone.qc.kernel.catalogue.hospital.beilun.operationdiscussion;

import com.alibaba.fastjson.JSONArray;
import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.client.ChiefPresentSimilarityServiceClient;
import com.lantone.qc.kernel.structure.ai.ModelAI;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.AnesthesiaRecordDoc;
import com.lantone.qc.pub.model.doc.operation.OperationDoc;
import com.lantone.qc.pub.util.DateUtil;
import com.lantone.qc.pub.util.StringUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.time.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * @ClassName: OPE03097
 * @Description: 手术开始时间与麻醉记录不一致
 * @Author songxl
 * @Date 2021/3/19
 * @Version 1.0
 */
@Component
@Slf4j
public class OPE03097 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        /**
         * 获取手术记录和麻醉记录手术开始时间 判断时间是否相同
         */
        status.set("0");
        //1.获取患者的手术相关文档,手麻记录
        List<OperationDoc> operationDocs = inputInfo.getOperationDocs();
        if(operationDocs==null||operationDocs.isEmpty())//无手术相关记录
        {
            return;
        }
        List<AnesthesiaRecordDoc> anesthesiaDocs  = inputInfo.getAnesthesiaRecordDocs();
        if(anesthesiaDocs==null|| anesthesiaDocs.isEmpty())//无手麻相关记录
        {
            return;
        }
        //2.遍历获取手术记录
       try{
           for(OperationDoc operationDoc:operationDocs)
           {
               if(operationDoc.getOperationRecordDoc()!=null)
               {
                   //2.1获取手术时间
                   Date operationEndTime = DateUtil.newParseDateTime(operationDoc.getOperationRecordDoc()
                           .getStructureMap().get("手术结束时间"));
                   Date operationStartTime = DateUtil.newParseDateTime(operationDoc.getOperationRecordDoc()
                           .getStructureMap().get("手术开始时间"));
                   if(operationStartTime==null||operationEndTime==null) {continue;}
                   anesthesiaDocs.forEach(anesthesiaRecordDoc -> {
                       if(anesthesiaRecordDoc.getAnesEndTime()!=null) {
                           if (DateUtils.isSameInstant(operationEndTime, anesthesiaRecordDoc.getAnesEndTime())) {
                               //2.2遍历手麻记录，对比手术时间开始时间
                               if(anesthesiaRecordDoc.getAnesStartTime()!=null)
                               {
                                   if(!DateUtils.isSameInstant(operationStartTime,anesthesiaRecordDoc.getAnesStartTime()))
                                   {
                                       status.set("-1");
                                       return;
                                   }
                               }
                           }
                       }
                   });
               }
           }
       }
       catch (Exception e)
       {
           log.error(e.getMessage(),e);
       }

    }
}
