package com.lantone.qc.kernel.catalogue.leavehospital;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.LeaveHospitalDoc;
import com.lantone.qc.pub.model.doc.operation.OperationDoc;
import com.lantone.qc.pub.util.StringUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @Description: 住院经过与手术记录中手术名称不一致
 * @author: wsy
 * @time: 2021/6/23 15:15
 */
@Component
@Slf4j
public class LEA03132 extends QCCatalogue {
    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        LeaveHospitalDoc leaveHospitalDoc = inputInfo.getLeaveHospitalDoc();
        List<OperationDoc> operationDocs = inputInfo.getOperationDocs();
        if (leaveHospitalDoc == null || operationDocs == null) {
            return;
        }

        //获取手术名称
        List<String> operationNameList = new ArrayList<>();
        for (OperationDoc operationDoc : operationDocs) {
            if (operationDoc.getOperationRecordDoc() != null) {
                String operationName = operationDoc.getOperationRecordDoc().getStructureMap().get("手术名称");
                if (StringUtil.isNotBlank(operationName)) {
                    operationNameList.add(operationName);
                }
            }
        }

        if (operationNameList.size() == 0) {
            return;
        }

        Map<String, String> structureMap = inputInfo.getLeaveHospitalDoc().getStructureMap();
        if (structureMap != null) {
            String curePass = structureMap.get("诊治经过");
            if (CatalogueUtil.isEmpty(curePass)) {
                return;
            }
            for (String operationName : operationNameList) {
                if (!curePass.contains(operationName)) {
                    status.set("-1");
                    return;
                }
            }
        }
    }
}