package com.lantone.qc.kernel.catalogue.operationdiscussion;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.operation.OperationDoc;
import com.lantone.qc.pub.model.doc.operation.OperationRecordDoc;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.text.ParseException;
import java.util.List;
import java.util.Map;

/**
 * @Description: 手术记录输血情况未填写
 * @author: kwz
 * @time: 2020/06/29 11:22
 */
@Component
public class OPE03143 extends QCCatalogue {
    /**
     * 标题形式包含【输血】判断是否为空
     * @param inputInfo
     * @param outputInfo
     */
    @Override
    protected void start(InputInfo inputInfo, OutputInfo outputInfo){
        status.set("0");
        //先判断有无手术记录
        List<OperationDoc> operationDocs = inputInfo.getOperationDocs();
        if(operationDocs != null && operationDocs.size()>0){
           for (OperationDoc operationDoc : operationDocs) {
                if(operationDoc==null){
                    continue;
                }
                OperationRecordDoc operationRecordDoc = operationDoc.getOperationRecordDoc();
                if(operationRecordDoc!=null){
                    Map<String, String> structureMap = operationRecordDoc.getStructureMap();
                    if(structureMap==null){
                        continue;
                    }
                    String bloodTransfusion = structureMap.get("输血情况");
                    if(StringUtil.isBlank(bloodTransfusion)){
                        status.set("-1");
                        return;
                    }
                }
            }
        }
    }
}