package com.lantone.qc.kernel.catalogue.operationdiscussion;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.operation.OperationDoc;
import com.lantone.qc.pub.model.doc.operation.OperationRecordDoc;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.text.ParseException;
import java.util.List;
import java.util.Map;

/**
 * @Description: 手术记录无主刀医师签字
 * @author: kwz
 * @time: 2020/06/29 11:22
 */
@Component
public class OPE03144 extends QCCatalogue {
    /**
     * 手术记录【主刀医师签名/审核签名】判断是否为空，任意一处和【手术医师】相同既为符合
     * @param inputInfo
     * @param outputInfo
     */
    @Override
    protected void start(InputInfo inputInfo, OutputInfo outputInfo){
        status.set("0");
        //先判断有无手术记录
        List<OperationDoc> operationDocs = inputInfo.getOperationDocs();
        if(operationDocs != null && operationDocs.size()>0){
           for (OperationDoc operationDoc : operationDocs) {
                if(operationDoc==null){
                    continue;
                }
                OperationRecordDoc operationRecordDoc = operationDoc.getOperationRecordDoc();
                if(operationRecordDoc!=null){
                    Map<String, String> structureMap = operationRecordDoc.getStructureMap();
                    if(structureMap==null){
                        continue;
                    }
             //
                    //获取【手术医师】
                    String surgeryName = structureMap.get("主刀医师");
                    String physiciansName = structureMap.get("主刀医师签名");
                    //获取审核人
                    String reviewerName = structureMap.get("审核人");
                    if((StringUtil.isNotBlank(physiciansName)||StringUtil.isNotBlank(reviewerName)) && StringUtil.isNotBlank(surgeryName)){
                        //主刀医师签名 与【手术医师】比较
                        status.set("-1");
                        if(StringUtil.isNotBlank(physiciansName)) {
                            if (surgeryName.equals(physiciansName)) {
                                status.set("0");
                                return;
                            }
                        }
                        if(StringUtil.isNotBlank(reviewerName)) {
                            if (surgeryName.equals(reviewerName)) {
                                status.set("0");
                                return;
                            }
                        }
                    }
                }
            }
        }
    }
}