package com.lantone.qc.kernel.catalogue.preoperativediscussion;

import com.lantone.qc.dbanaly.util.KernelConstants;
import com.lantone.qc.dbanaly.util.SpecialStorageUtil;
import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.operation.OperationDoc;
import com.lantone.qc.pub.model.doc.operation.PreoperativeDiscussionDoc;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * @Description: 术前讨论记录未记录讨论者的姓名及职称
 * @author: rengb
 * @time: 2020/3/23 15:09
 */
@Component
public class PRE0580 extends QCCatalogue {
    @Autowired
    private SpecialStorageUtil specialStorageUtil;

    @Override
    protected void start(InputInfo inputInfo, OutputInfo outputInfo){
        /**
         * 术前讨论、术前小结存在的前提       【参加人员】判断是否为空，并【姓名】加职称：【主治/助理/主任/副主任/规培/实习/住院/院长】
         */
        status.set("0");
        List<OperationDoc> operationDocs = inputInfo.getOperationDocs();
        if(ListUtil.isEmpty(operationDocs)){
            return;
        }
        for (OperationDoc operationDoc : operationDocs) {
            PreoperativeDiscussionDoc preoperativeDiscussionDoc = operationDoc.getPreoperativeDiscussionDoc();
            if (preoperativeDiscussionDoc != null) {
                Map<String, String> structureMap = preoperativeDiscussionDoc.getStructureMap();
                if (structureMap == null) {
                    continue;
                }
                String participants = structureMap.get("参加人员");
                if (StringUtil.isBlank(participants)) {
                    if(!participantsSplit(participants)) {
                        status.set("-1");
                        return;
                    }
                }

            }
        }
    }

    //对参加人员进行切割并判断
    private boolean participantsSplit( String participants ) {
        List<String> punctuationList = Content.punctuationList;
        for (String punctuation : punctuationList) {
            if(participants.contains(punctuation)){
                String[] strings = punctuation.split(punctuation);
                for (String string : strings) {
                    if(!findDirectorDoctor(string)){
                        return false;
                    }
                }
            }
        }
        return true;
    }

    private boolean findDirectorDoctor(String string) {
        Map<String, Map<String, Object>> hospitalDoctorMap = specialStorageUtil.getJsonStringValue(KernelConstants.HOSPITAL_DOCTOR_MAP);
        if (hospitalDoctorMap == null) {
            return true;
        }
        for (String keyStr : hospitalDoctorMap.keySet()) {
            if (string.contains(keyStr)) {
                Object professor = hospitalDoctorMap.get(keyStr).get("professor");
                if (professor != null) {
                    if (!string.contains(professor.toString())) {
                        return false;
                    }

                }
            }
        }
        return true;
    }

}