package com.lantone.qc.kernel.catalogue.threelevelward;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.*;
import com.lantone.qc.pub.model.doc.consultation.ConsultationApplicationDoc;
import com.lantone.qc.pub.model.doc.consultation.ConsultationDoc;
import com.lantone.qc.pub.model.doc.operation.OperationDiscussionDoc;
import com.lantone.qc.pub.model.doc.operation.OperationDoc;
import com.lantone.qc.pub.model.doc.transferrecord.TransferIntoDoc;
import com.lantone.qc.pub.model.doc.transferrecord.TransferOutDoc;
import com.lantone.qc.pub.model.doc.transferrecord.TransferRecordDoc;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;


import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * @ClassName : THR03118
 * @Description: 报告单或病程记录缺少细菌培养记录
 * @author: zh
 * @time: 2021/04/06 11:22
 */
@Component
public class THR03121 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        boolean flag = false;
        boolean coolCf = false;
        boolean coolBg = false;
        List<DoctorAdviceDoc> doctorAdviceDocList = inputInfo.getDoctorAdviceDocs();
        List<ThreeLevelWardDoc> threeLevelWardDocs = inputInfo.getThreeLevelWardDocs();
        //是否进行过细菌培养
        //医嘱判断
        if (ListUtil.isNotEmpty(doctorAdviceDocList)) {
       xj: for (DoctorAdviceDoc doctorAdviceDoc : doctorAdviceDocList) {
            Map<String, String> doctorAdviceDocStructureMap = doctorAdviceDoc.getStructureMap();
            String daStatus = doctorAdviceDocStructureMap.get(Content.doctorAdviceState);
                  if (StringUtil.isNotEmpty(daStatus)) {
                if (!Content.cancellationOrderList.contains(daStatus)) {
            String doctorAsks = doctorAdviceDocStructureMap.get(Content.doctorAdviceType);
            if (Content.statOrder.equals(doctorAsks)) {
                String doctorAsksName = doctorAdviceDocStructureMap.get(Content.medicalOrderName);
                if (StringUtil.isNotEmpty(doctorAsksName)) {
                    if (dateStr(doctorAsksName)) {
                        flag=true;
                        break xj;
                            }
                        }
                    }
                }
            }
           }
        }
        //查房记录
        if(ListUtil.isNotEmpty(threeLevelWardDocs)) {
            List<ThreeLevelWardDoc> allDoctorWradDocs = threeLevelWardDocs.get(0).getAllDoctorWradDocs();
            for (ThreeLevelWardDoc allDoctorWradDoc : allDoctorWradDocs) {
                String illness = allDoctorWradDoc.getStructureMap().get(Content.illnessRecords);
                if(dateStr(illness)){
                    flag=true;
                    break;
                }
            }
        }
        List<LisDoc> lisDocs = inputInfo.getLisDocs();
        //报告单
        if (ListUtil.isNotEmpty(lisDocs)) {
            for (LisDoc lisDoc : lisDocs) {
                String lisDocStr = lisDoc.getStructureMap().get(Content.reportName);
                if (StringUtil.isNotEmpty(lisDocStr)) {
                    if (dateStr(lisDocStr)) {
                        flag = true;
                        break;
                    }
                }
            }
        }
/**
 * 使用过细菌培养 是否有记录
 */
        if(flag) {
            status.set("-1");
            //查房
            if (ListUtil.isNotEmpty(threeLevelWardDocs)) {
                List<ThreeLevelWardDoc> allDoctorWradDocs = threeLevelWardDocs.get(0).getAllDoctorWradDocs();
                for (ThreeLevelWardDoc allDoctorWradDoc : allDoctorWradDocs) {
                    String illness = allDoctorWradDoc.getStructureMap().get(Content.illnessRecords);
                    if (dateStr(illness)) {
                        coolCf = true;
                        break;
                    }
                }
            }
            //报告
            if (ListUtil.isNotEmpty(lisDocs)) {
                for (LisDoc lisDoc : lisDocs) {
                    String lisDocStr = lisDoc.getStructureMap().get(Content.reportName);
                    if (StringUtil.isNotEmpty(lisDocStr)) {
                        if (dateStr(lisDocStr)) {
                            coolBg = true;
                            break;
                        }
                    }
                }
            }
            if(coolCf||coolBg){
                status.set("0");
                return;
            }
        }


    }
    private boolean dateStr(String str){
        if(StringUtil.isEmpty(str)){
            return false;
        }
        str = str.replaceAll("\\*", "\\\\*");
        str = str.replaceAll("\\)", "\\\\)");
        str = str.replaceAll("\\.", "\\\\.");
        str = str.replaceAll("\\?", "\\\\?");
        str = str.replaceAll("\\+", "\\\\+");
        str = str.replaceAll("\\$", "\\\\$");
        str = str.replaceAll("\\^", "\\\\^");
        str = str.replaceAll("\\[", "\\\\[");
        str = str.replaceAll("\\]", "\\\\]");
        str = str.replaceAll("\\(", "\\\\(");
        str = str.replaceAll("\\{", "\\\\{");
        str = str.replaceAll("\\}", "\\\\}");
        str = str.replaceAll("\\|", "\\\\|");
        str = str.replaceAll("\\/", "\\\\/");
        String rex1="[\\s\\S]*(?=痰)[^,;，；。]{0,7}(?=培养)[\\s\\S]*";
        String rex2="[\\s\\S]*(?=尿)[^,;，；。]{0,7}(?=培养)[\\s\\S]*";
        String rex3="[\\s\\S]*(?=细菌)[^,;，；。]{0,7}(?=培养)[\\s\\S]*";
        String rex4="[\\s\\S]*(?=咽)[^,;，；。]{0,7}(?=拭子)[\\s\\S]*";
        String rex5="[\\s\\S]*(?=血)[^,;，；。]{0,7}(?=培养)[\\s\\S]*";
        String rex6="[\\s\\S]*(?=菌培养)[\\s\\S]*";
        String rex7="[\\s\\S]*(?=骨髓)[^,;，；。]{0,7}(?=培养)[\\s\\S]*";
        if (str.contains("粪便培养") || str.matches(rex1)|| str.matches(rex2)|| str.matches(rex3)
                || str.matches(rex4) || str.matches(rex5) || str.matches(rex6) ||str.matches(rex7)) {
            return true;
        }
        return false;
    }
}
