package com.lantone.qc.kernel.catalogue.threelevelward;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.*;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @ClassName : THR03119
 * @Description: 有抗菌药物使用病程无记录
 * @author: zh
 * @time: 2021/04/06 11:22
 */
@Component
public class THR03122 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        boolean flag = false;
        FirstPageRecordDoc firstPageRecordDoc = inputInfo.getFirstPageRecordDoc();
        List<ThreeLevelWardDoc> threeLevelWardDocs = inputInfo.getThreeLevelWardDocs();
        List<String> antimicrobialDrugList = Content.antimicrobialDrugList;
        List<String> cfAntibacterialList = Content.cfAntibacterialList;
        String drugAllergy = "";
        String drugAllergyStr="";
        //判断是否有抗菌药物的使用
        //首页费用
        if (firstPageRecordDoc != null) {
            Map<String, String> structureMap = firstPageRecordDoc.getStructureMap();
            String antimicrobialAgents = structureMap.get("抗菌药物费用");
            if (StringUtil.isNotEmpty(antimicrobialAgents) && antimicrobialAgents.equals("0")) {
                double b = Double.parseDouble(antimicrobialAgents);
                if (b > 0) {
                    flag = true;
                }
            }
            drugAllergy = structureMap.get("过敏药物")+drugAllergy;
            drugAllergyStr = structureMap.get("药物过敏")+drugAllergyStr;
        }
            //查医嘱
            List<DoctorAdviceDoc> doctorAdviceDocs = inputInfo.getDoctorAdviceDocs();
            for (DoctorAdviceDoc doctorAdviceDoc : doctorAdviceDocs) {
                Map<String, String> structureMap = doctorAdviceDoc.getStructureMap();
                String daStatus = structureMap.get(Content.doctorAdviceState);
                if (StringUtil.isNotEmpty(daStatus)) {
                    if (!Content.cancellationOrderList.contains(daStatus)) {
                        String adviceType = structureMap.get(Content.doctorAdviceType);
                        String drugType = structureMap.get(Content.drugType);
                        //取长期和临时医嘱
                        if (adviceType.equals(Content.statOrder) || adviceType.equals(Content.standingOrder)) {
                            //取医嘱药品类型为抗生素的医嘱
                            if (StringUtil.isNotEmpty(drugType)) {
                                if(drugType.equals("抗生素")) {
                                    String daItemName = structureMap.get(Content.medicalOrderName);
                                    for (String antimicrobialDrug : antimicrobialDrugList) {
                                        if (daItemName.contains(antimicrobialDrug)) {
                                            //排除过敏药物的情况
                                            if ((StringUtil.isEmpty(drugAllergy) || drugAllergy.equals("")) && (StringUtil.isEmpty(drugAllergyStr) || drugAllergyStr.equals(""))) {
                                                flag = true;
                                                break;
                                            }
                                            if (!drugAllergy.contains(antimicrobialDrug) && !drugAllergyStr.contains(antimicrobialDrug)) {
                                                flag = true;
                                                break;
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
            //查房记录
        if(ListUtil.isNotEmpty(threeLevelWardDocs)) {
            List<ThreeLevelWardDoc> allDoctorWradDocs = threeLevelWardDocs.get(0).getAllDoctorWradDocs();
            for (ThreeLevelWardDoc allDoctorWradDoc : allDoctorWradDocs) {
                String illness = allDoctorWradDoc.getStructureMap().get(Content.illnessRecords);
                for (String antimicrobialDrug : antimicrobialDrugList) {
                    if (illness.contains(antimicrobialDrug)) {
                        if((StringUtil.isEmpty(drugAllergy)||drugAllergy.equals(""))&&(StringUtil.isEmpty(drugAllergyStr)||drugAllergyStr.equals(""))){
                            flag = true;
                            break;
                        }
                        if(!drugAllergy.contains(antimicrobialDrug)&&!drugAllergyStr.contains(antimicrobialDrug)){
                            flag=true;
                            break;
                        }
                    }
                }
                for (String cfAntibacterial : cfAntibacterialList) {
                    if(illness.contains(cfAntibacterial)){
                        flag = true;
                        break;
                    }
                }
            }
        }
        //使用过抗菌药物，是否有记录
        if (flag) {
            status.set("-1");
            if (ListUtil.isNotEmpty(threeLevelWardDocs)) {
                ThreeLevelWardDoc threeLevelWardDoc = threeLevelWardDocs.get(0);
                List<ThreeLevelWardDoc> allDoctorWradDocs = threeLevelWardDoc.getAllDoctorWradDocs();
                if (ListUtil.isNotEmpty(allDoctorWradDocs)) {
                    for (ThreeLevelWardDoc allDoctorWradDoc : allDoctorWradDocs) {
                        Map<String, String> wradDocStructureMap = allDoctorWradDoc.getStructureMap();
                        String illnessRecords = wradDocStructureMap.get(Content.illnessRecords);
                        if (StringUtil.isNotEmpty(illnessRecords)) {
                            for (String antimicrobial : antimicrobialDrugList) {
                                if (illnessRecords.contains(antimicrobial)) {
                                    status.set("0");
                                    return;
                                }
                            }
                            for (String cfAntibacterial : cfAntibacterialList) {
                                if(illnessRecords.contains(cfAntibacterial)){
                                    status.set("0");
                                    return;
                                }
                            }
                        }
                    }
                }
            }
        }
    }
}
