package com.lantone.qc.kernel.catalogue.threelevelward;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.DoctorAdviceDoc;
import com.lantone.qc.pub.model.doc.FirstCourseRecordDoc;
import com.lantone.qc.pub.model.doc.FirstPageRecordDoc;
import com.lantone.qc.pub.model.doc.LeaveHospitalDoc;
import com.lantone.qc.pub.model.doc.transferrecord.TransferIntoDoc;
import com.lantone.qc.pub.model.doc.transferrecord.TransferOutDoc;
import com.lantone.qc.pub.model.doc.transferrecord.TransferRecordDoc;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @ClassName : THR03137
 * @Description : 缺转入记录
 * @Author : rengb
 * @Date: 2020-03-06 17:28
 */
@Component
public class THR03137 extends QCCatalogue {

    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        boolean flag=false;
        //首先判断医嘱中是否包含转科相关信息
        List<DoctorAdviceDoc> doctorAdviceDocs = inputInfo.getDoctorAdviceDocs();
        if(ListUtil.isEmpty(doctorAdviceDocs)){
            return;
        }
        //1.1【首次病程录】“科别”和【出院小结】“科别”不一致为转科
        FirstCourseRecordDoc firstCourseRecordDoc = inputInfo.getFirstCourseRecordDoc();
        LeaveHospitalDoc leaveHospitalDoc = inputInfo.getLeaveHospitalDoc();
        if(null != firstCourseRecordDoc && StringUtils.isNotBlank(firstCourseRecordDoc.getStructureMap().get("临床科室")) &&  null != leaveHospitalDoc && StringUtils.isNotBlank(leaveHospitalDoc.getStructureMap().get("临床科室"))){
            String deptFir = firstCourseRecordDoc.getStructureMap().get("临床科室");
            String deptSec= leaveHospitalDoc.getStructureMap().get("临床科室");
            if(!deptFir.equals(deptSec)){
                flag = true;
            }
        }
        //1.2【病案首页】“入院科别”和“出院科别”不一致为转科
        FirstPageRecordDoc firstPageRecordDoc = inputInfo.getFirstPageRecordDoc();
        if(null != firstPageRecordDoc && StringUtils.isNotBlank(firstPageRecordDoc.getStructureMap().get("入院科别")) &&
                StringUtils.isNotBlank(firstPageRecordDoc.getStructureMap().get("出院科别"))){
            String deptFir = firstPageRecordDoc.getStructureMap().get("入院科别");
            String deptSec= firstPageRecordDoc.getStructureMap().get("出院科别");
            if(!deptFir.equals(deptSec)){
                flag = true;
            }
        }
        for (DoctorAdviceDoc doctorAdviceDoc : doctorAdviceDocs) {
            //取长期临时医嘱,不为作废医嘱
            if(doctorAdviceDoc.getStructureMap()!=null){
                Map<String, String> doctorAdviceDocStructureMap = doctorAdviceDoc.getStructureMap();
                String adviceType = doctorAdviceDocStructureMap.get(Content.doctorAdviceType);
                if(StringUtil.isNotEmpty(adviceType)){
                    if(adviceType.equals(Content.standingOrder)||adviceType.equals(Content.statOrder)){
                        String adviceState = doctorAdviceDocStructureMap.get(Content.doctorAdviceState);
                        if(StringUtil.isNotEmpty(adviceState)){
                            if(!Content.cancellationOrderList.contains(adviceState)){
                                String medicalOrderName = doctorAdviceDoc.getStructureMap().get(Content.medicalOrderName);
                                if(StringUtil.isBlank(medicalOrderName)) {
                                    continue;
                                }
                                if(medicalOrderName.startsWith("停")){
                                    continue;
                                }
                                //1.3【临时医嘱/长期医嘱】包含【转科医嘱】4字
                                if(medicalOrderName.contains("转科医嘱")){
                                    flag = true;
                                    break;
                                }
                            }
                        }
                    }
                }
            }
        }
        //1.4为转科人员判断是否有【转入记录/转科记录】
        if(flag){
            status.set("-1");
            TransferRecordDoc transferRecordDocs = inputInfo.getTransferRecordDocs();
            if(transferRecordDocs==null){
                return;
            }
            List<TransferIntoDoc> transferIntoDocs = transferRecordDocs.getTransferIntoDocs();
            if(ListUtil.isNotEmpty(transferIntoDocs) && transferIntoDocs.size()>0){
                //转入记录存在
                status.set("0");
                return;
            }

        }

        //2.1不存在【转入记录】或【转出记录】与【转入记录】数量不一致则报
        status.set("0");
        TransferRecordDoc transferRecordDocs = inputInfo.getTransferRecordDocs();
        if(transferRecordDocs==null){
            return;
        }
        List<TransferIntoDoc> transferIntoDocs = transferRecordDocs.getTransferIntoDocs();
        List<TransferOutDoc> transferOutDocs = transferRecordDocs.getTransferOutDocs();
        if(ListUtil.isEmpty(transferIntoDocs) || (transferIntoDocs.size()>0 && transferIntoDocs.size() != transferOutDocs.size())){
            status.set("-1");
            return;
        }

    }


}