package com.lantone.qc.kernel.catalogue.threelevelward;

import com.lantone.qc.dbanaly.util.KernelConstants;
import com.lantone.qc.dbanaly.util.SpecialStorageUtil;
import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.DeathRecordDoc;
import com.lantone.qc.pub.model.doc.DoctorAdviceDoc;
import com.lantone.qc.pub.model.doc.ThreeLevelWardDoc;
import com.lantone.qc.pub.util.DateUtil;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @ClassName : THR03147
 * @Description : 患者出院前48小时内无上级医师(主治及以上)同意出院的病程记录
 * @Author : 胡敬
 * @Date: 2020-03-19 13:51
 */
@Component
public class THR03147 extends QCCatalogue {
    @Autowired
    private SpecialStorageUtil specialStorageUtil;
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        if(inputInfo.getFirstPageRecordDoc()==null || inputInfo.getFirstPageRecordDoc().getStructureMap()==null){
            return;
        }
        //死亡记录不为空
        DeathRecordDoc deathRecordDoc = inputInfo.getDeathRecordDoc();
        if(deathRecordDoc!=null){
            return;
        }
        List<String> noDeathList = Content.noDeathList;
        //死亡患者不判断
        List<DoctorAdviceDoc> doctorAdviceDocs = inputInfo.getDoctorAdviceDocs();
        if(ListUtil.isNotEmpty(doctorAdviceDocs)){
            sw: for (DoctorAdviceDoc doctorAdviceDoc : doctorAdviceDocs) {
                //取长期临时医嘱,不为作废医嘱
                if(doctorAdviceDoc.getStructureMap()==null) {
                    continue;
                }
                Map<String, String> doctorAdviceDocStructureMap = doctorAdviceDoc.getStructureMap();
                String adviceType = doctorAdviceDocStructureMap.get(Content.doctorAdviceType);
                if (StringUtil.isEmpty(adviceType)) {
                    continue;
                }
                if (adviceType.equals(Content.standingOrder) || adviceType.equals(Content.statOrder)) {
                    String adviceState = doctorAdviceDocStructureMap.get(Content.doctorAdviceState);
                    if (StringUtil.isEmpty(adviceState)) {
                        continue;
                    }
                    if (!Content.cancellationOrderList.contains(adviceState)) {
                        //死亡医嘱
                        String medicalOrderName = doctorAdviceDoc.getStructureMap().get(Content.medicalOrderName);
                        if(StringUtil.isBlank(medicalOrderName)) {
                            continue;
                        }
                        if(medicalOrderName.startsWith("停")){
                            continue;
                        }
                        if (medicalOrderName.contains("死亡")) {
                            for (String noDeath : noDeathList) {
                                if(medicalOrderName.contains(noDeath)){
                                    continue sw;
                                }
                            }
                            return;
                        }
                    }
                }
            }
        }
        //获取病案首页出院时间
        String dischargeTime = inputInfo.getFirstPageRecordDoc().getStructureMap().get("出院时间");
        if (CatalogueUtil.isEmpty(dischargeTime)) {
            return;
        }
        Date dischargeDate = StringUtil.parseDateTime(dischargeTime);
        List<ThreeLevelWardDoc> threeLevelWardDocs = inputInfo.getThreeLevelWardDocs();
        if(ListUtil.isEmpty(threeLevelWardDocs)){
            return;
        }
        List<ThreeLevelWardDoc> allDoctorWradDocs = threeLevelWardDocs.get(0).getAllDoctorWradDocs();
        if(ListUtil.isEmpty(allDoctorWradDocs)){
            return;
        }
        if(!getAllPatientRounds(allDoctorWradDocs,dischargeDate)){
            status.set("-1");
            return;
        }

    }


    //获取患者出院前48小时内所有的查房记录并判断
    public  boolean getAllPatientRounds(List<ThreeLevelWardDoc> allDoctorWradDocs ,Date dischargeDate){
        boolean flag=true;
        List<String> superiorList = Content.superiorList;
        for (ThreeLevelWardDoc allDoctorWradDoc : allDoctorWradDocs) {
            Map<String, String> structureMap = allDoctorWradDoc.getStructureMap();
            if(structureMap==null){
                continue;
            }
            String checkTheTime = structureMap.get("查房日期");
            if (CatalogueUtil.isEmpty(checkTheTime)) {
                continue;
            }
            Date checkTheDate = StringUtil.parseDateTime(checkTheTime);
            if(!CatalogueUtil.compareTime(
                    checkTheDate,
                    dischargeDate,
                    Long.valueOf(48 * 60))&&checkTheDate.before(dischargeDate)){
                flag=false;
                //出院前48小时的查房记录
                String key = getKeyByHospitalId();
                String illnessRecords = structureMap.get(key);
                //包含出院
                if(StringUtil.isNotEmpty(illnessRecords)){
                if(illnessRecords.contains("出院")) {
                    // 查房记录标题或查房记录内容或医生签字包含【上级/主任/主治/主治及以上医师姓名】
                    String roundTitle = structureMap.get("查房标题");
                    //标题判断
                    if (StringUtil.isNotEmpty(roundTitle)) {
                        for (String superior : superiorList) {
                            if (roundTitle.contains(superior)) {
                                flag=true;
                                return flag;
                            }
                        }
                       if(judgeContainsDoctor(roundTitle)){
                            flag=true;
                           return flag;
                        }
                    }
                    //查房记录判断
                        for (String superior : superiorList) {
                            if (illnessRecords.contains(superior)) {
                                flag=true;
                                return flag;
                            }
                        }
                    if(judgeContainsDoctor(illnessRecords)){
                        flag=true;
                        return flag;
                    }
                    //审核人判断
                    String reviewer = structureMap.get("审核人");
                    if (StringUtil.isNotEmpty(reviewer)) {
                        for (String superior : superiorList) {
                            if (reviewer.contains(superior)) {
                                flag=true;
                                return flag;
                            }
                        }
                        if(judgeContainsDoctor(reviewer)){
                            flag=true;
                            return flag;
                        }
                    }
                    //记录医师判断
                    String recordsPhysicians = structureMap.get("记录医师");
                    if (StringUtil.isNotEmpty(recordsPhysicians)) {
                        for (String superior : superiorList) {
                            if (recordsPhysicians.contains(superior)) {
                                flag=true;
                                return flag;
                            }
                        }
                        if(judgeContainsDoctor(recordsPhysicians)){
                            flag=true;
                            return flag;
                        }
                    }
                }
                }
            }
        }
        return flag;
    }

    //判断是否含有主治及以上医师姓名
    private boolean judgeContainsDoctor(String string) {
        List<String> indicationsAboveList = Content.indicationsAboveList;
        Map<String, Map<String, Object>> hospitalDoctorMap = specialStorageUtil.getJsonStringValue(KernelConstants.HOSPITAL_DOCTOR_MAP);
        if (hospitalDoctorMap == null) {
            return false;
        }
        //主治及以上   主治，主任，副主任
        for (String keyStr : hospitalDoctorMap.keySet()) {
            if (string.contains(keyStr)) {
                Object professor = hospitalDoctorMap.get(keyStr).get("professor");
                if (professor != null) {
                    for (String indicationsAbove : indicationsAboveList) {
                        if (professor.toString().contains(indicationsAbove)) {
                            return true;
                        }
                    }
                }
            }
        }
        return false;
    }

    private String getKeyByHospitalId() {
        switch (Content.hospital_Id)
        {
            case "3":               //台州
                return "查房内容";
            default:
                return "病情记录";
        }
    }

}