package com.lantone.qc.kernel.catalogue.threelevelward;

import com.lantone.qc.dbanaly.util.KernelConstants;
import com.lantone.qc.dbanaly.util.SpecialStorageUtil;
import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.*;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.SpringContextUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.time.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @ClassName : THR03149
 * @Description :  抢救患者上级医师(副高及以上)查房记录不及时
 * @Author : Mark
 * @Date: 2020-04-07 17:06
 */
@Component
public class THR03149 extends QCCatalogue {
    @Autowired
    private SpecialStorageUtil specialStorageUtil;
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        boolean falg=false;
        List<String> noDeathList = Content.noDeathList;
        List<DoctorAdviceDoc> doctorAdviceDocs = inputInfo.getDoctorAdviceDocs();
        List<RescueDoc> rescueDocs = inputInfo.getRescueDocs();
        //死亡记录不为空
        DeathRecordDoc deathRecordDoc = inputInfo.getDeathRecordDoc();
        if(deathRecordDoc!=null){
            return;
        }
        MedicalRecordInfoDoc medicalRecordInfoDoc = inputInfo.getMedicalRecordInfoDoc();

        if(ListUtil.isNotEmpty(doctorAdviceDocs)){
            sw:  for (DoctorAdviceDoc doctorAdviceDoc : doctorAdviceDocs) {
                //取长期临时医嘱,不为作废医嘱
                if(doctorAdviceDoc.getStructureMap()==null) {
                    continue;
                }
                Map<String, String> doctorAdviceDocStructureMap = doctorAdviceDoc.getStructureMap();
                String adviceType = doctorAdviceDocStructureMap.get(Content.doctorAdviceType);
                if (StringUtil.isEmpty(adviceType)) {
                    continue;
                }
                if (adviceType.equals(Content.standingOrder) || adviceType.equals(Content.statOrder)) {
                    String adviceState = doctorAdviceDocStructureMap.get(Content.doctorAdviceState);
                    if (StringUtil.isEmpty(adviceState)) {
                        continue;
                    }
                    if (!Content.cancellationOrderList.contains(adviceState)) {
                        //死亡医嘱
                        String medicalOrderName = doctorAdviceDoc.getStructureMap().get(Content.medicalOrderName);
                        if(StringUtil.isBlank(medicalOrderName)) {
                            continue;
                        }
                        if(medicalOrderName.startsWith("停")){
                            continue;
                        }
                            if (medicalOrderName.contains("死亡")) {
                                for (String noDeath : noDeathList) {
                                    if(medicalOrderName.contains(noDeath)){
                                        continue sw;
                                    }
                                }
                                return;
                            }
                            if (medicalOrderName.contains("抢救")) {
                                falg = true;
                            }
                    }
                }
            }
        }
        //为一个抢救患者
        if(ListUtil.isNotEmpty(rescueDocs)){
            falg=true;
        }
        if(falg){
            //获取抢救时间
            if(ListUtil.isEmpty(rescueDocs)){
                return;
            }
            for (RescueDoc rescueDoc : rescueDocs) {
                String saveTime = rescueDoc.getStructureMap().get("抢救开始时间");
                if(StringUtil.isBlank(saveTime)){
                    continue;
                }
                Date saveDate = StringUtil.parseDateTime(saveTime);
                if(medicalRecordInfoDoc!=null){
                    //获取出院时间
                    String leaveHospitalTime = medicalRecordInfoDoc.getStructureMap().get("leaveHospitalDate");
                    if(StringUtil.isNotBlank(leaveHospitalTime)){
                        Date leaveHospitalDate = StringUtil.parseDateTime(leaveHospitalTime);
                        if(DateUtils.isSameDay(leaveHospitalDate, saveDate)){
                            //出院和抢救记录为同一天则跳过
                            continue;
                        }
                    }

                }
                if(getAllSaveDoctor(inputInfo,outputInfo,saveDate)){
                    return;
                }else {
                    //去【抢救记录】内找是否有包含【上级医师姓名】/【主任】字段，若无报出
                    String text = rescueDoc.getText();
                    if(StringUtil.isNotBlank(text)){
                        if(!text.contains("主任")&&!judgeContainsDoctor(text)){
                            status.set("-1");
                            return;
                        }
                    }
                }
            }
        }
    }
    //抢救6小时内 找标题为【主任*查房】或【主任级别的姓名查房】
    public  boolean getAllSaveDoctor(InputInfo inputInfo, OutputInfo outputInfo,Date saveDate ) {
        List<ThreeLevelWardDoc> threeLevelWardDocs = inputInfo.getThreeLevelWardDocs();
        if (ListUtil.isEmpty(threeLevelWardDocs)) {
            return false;
        }
        List<ThreeLevelWardDoc> allDoctorWradDocs = threeLevelWardDocs.get(0).getAllDoctorWradDocs();
        if (ListUtil.isEmpty(allDoctorWradDocs)) {
            return false;
        }
        for (ThreeLevelWardDoc allDoctorWradDoc : allDoctorWradDocs) {
            Map<String, String> structureMap = allDoctorWradDoc.getStructureMap();
            String checkTime = structureMap.get("查房日期");
            if(StringUtil.isBlank(checkTime)){
                continue;
            }
            Date checkDate = StringUtil.parseDateTime(checkTime);
            if (!CatalogueUtil.compareTime(
                    saveDate,
                    checkDate,
                    Long.valueOf(6 * 60))&&saveDate.before(checkDate)) {
                //不大于抢救开始时间6小时内，取查房标题
                String wardRoundTitle = structureMap.get("查房标题");
                //【主任*查房】或【主任级别的姓名查房】
                if(StringUtil.isBlank(wardRoundTitle)){
                    continue;
                }
                if(wardRoundTitle.contains("主任")){
                    return true;
                }
                if(judgeContainsDoctor(wardRoundTitle)){
                    return true;
                }
            }
        }
        return false;
    }

    //判断是否含有主任医师姓名
    private boolean judgeContainsDoctor(String string) {
        Map<String, Map<String, Object>> hospitalDoctorMap = specialStorageUtil.getJsonStringValue(KernelConstants.HOSPITAL_DOCTOR_MAP);
        if (hospitalDoctorMap == null) {
            return false;
        }
        for (String keyStr : hospitalDoctorMap.keySet()) {
            if (string.contains(keyStr)) {
                Object professor = hospitalDoctorMap.get(keyStr).get("professor");
                if (professor != null) {
                        if (professor.toString().contains("主任")) {
                            return true;
                        }
                }
            }
        }
        return false;
    }
}