package com.lantone.qc.kernel.catalogue.threelevelward;

import com.lantone.qc.dbanaly.util.KernelConstants;
import com.lantone.qc.dbanaly.util.SpecialStorageUtil;
import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.kernel.util.CatalogueUtil;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.FirstPageRecordDoc;
import com.lantone.qc.pub.model.doc.LeaveHospitalDoc;
import com.lantone.qc.pub.model.doc.MedicalRecordInfoDoc;
import com.lantone.qc.pub.model.doc.ThreeLevelWardDoc;
import com.lantone.qc.pub.util.DateUtil;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @ClassName : THR03151
 * @Description :  缺副高以上医师（医疗组长）查房记录
 * @Author : Mark
 * @Date: 2020-04-07 17:06
 */
@Component
public class THR03151 extends QCCatalogue {
    @Autowired
    private SpecialStorageUtil specialStorageUtil;
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        boolean flag=false;
        boolean getTime=false;
        //先从病案首页取入院出院时间
        FirstPageRecordDoc firstPageRecordDoc = inputInfo.getFirstPageRecordDoc();
        if(firstPageRecordDoc!=null){
            String admisTime = firstPageRecordDoc.getStructureMap().get("入院时间");
            String dischargeTime = firstPageRecordDoc.getStructureMap().get("出院时间");
            if(CatalogueUtil.isEmpty(admisTime) || CatalogueUtil.isEmpty(dischargeTime)){
                //病案首页时间不存在则去出院小结取
                getTime=true;
            }else {
                //不为空如果住院天数小于2天则不判断该条规则
                if (DateUtil.parseDate(dischargeTime) != null &&
                        !CatalogueUtil.compareTime(StringUtil.parseDateTime(admisTime), StringUtil.parseDateTime(dischargeTime), (long) (72 * 60))) {
                    return;
                } else {
                    flag=true;
                }
            }
        }
        if(getTime){
            //
            LeaveHospitalDoc leaveHospitalDoc = inputInfo.getLeaveHospitalDoc();
            if(leaveHospitalDoc!=null){
                String admisTime = firstPageRecordDoc.getStructureMap().get("入院时间");
                String dischargeTime = firstPageRecordDoc.getStructureMap().get("出院时间");
                if(CatalogueUtil.isEmpty(admisTime) || CatalogueUtil.isEmpty(dischargeTime)){
                    //病案首页时间不存在则去出院小结取
                    return;
                }else {
                    //不为空如果住院天数小于2天则不判断该条规则
                    if (DateUtil.parseDate(dischargeTime) != null &&
                            !CatalogueUtil.compareTime(StringUtil.parseDateTime(admisTime), StringUtil.parseDateTime(dischargeTime), (long) (72 * 60))) {
                        return;
                    } else {
                        flag=true;
                    }
                }
            }
        }
        if(flag){
            //判断查房
            status.set("-1");
            List<ThreeLevelWardDoc> threeLevelWardDocs = inputInfo.getThreeLevelWardDocs();
            if(ListUtil.isEmpty(threeLevelWardDocs)){
                return;
            }
            List<ThreeLevelWardDoc> allDoctorWradDocs = threeLevelWardDocs.get(0).getAllDoctorWradDocs();
            if(ListUtil.isEmpty(allDoctorWradDocs)){
                return;
            }
            for (ThreeLevelWardDoc allDoctorWradDoc : allDoctorWradDocs) {
                String wardRoundTitle = allDoctorWradDoc.getStructureMap().get("查房标题");
                if(StringUtil.isNotBlank(wardRoundTitle)){
                    if(wardRoundTitle.contains("主任")||judgeContainsDoctor(wardRoundTitle)){
                        status.set("0");
                        return;
                    }
                }
            }
        }
    }

    //判断是否含有主任医师姓名
    private boolean judgeContainsDoctor(String string) {
        Map<String, Map<String, Object>> hospitalDoctorMap = specialStorageUtil.getJsonStringValue(KernelConstants.HOSPITAL_DOCTOR_MAP);
        if (hospitalDoctorMap == null) {
            return false;
        }
        for (String keyStr : hospitalDoctorMap.keySet()) {
            if (string.contains(keyStr)) {
                Object professor = hospitalDoctorMap.get(keyStr).get("professor");
                if (professor != null) {
                    if (professor.toString().contains("主任")) {
                        return true;
                    }
                }
            }
        }
        return false;
    }
}