package com.lantone.qc.trans.beilun;

import com.google.common.collect.Lists;
import com.lantone.qc.pub.model.doc.InformedConsentDoc;
import com.lantone.qc.pub.model.vo.MedrecVo;
import com.lantone.qc.pub.util.FastJsonUtils;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import com.lantone.qc.trans.ModelDocTrans;
import com.lantone.qc.trans.beilun.util.BeiLunHtmlAnalysis;
import com.lantone.qc.trans.beilun.util.BeiLunInformedHtmlAnalysis;
import com.lantone.qc.trans.comsis.CommonAnalysisUtil;
import com.lantone.qc.trans.comsis.ModelDocGenerate;
import com.lantone.qc.trans.comsis.OrdinaryAssistant;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.MapUtils;

import java.util.List;
import java.util.Map;

/**
 * @Description: 知情同意书
 * @author: cy
 * @time: 2021/4/18 17:48
 */
@Slf4j
public class BeilunInformedConsentDocTrans extends ModelDocTrans {
    @Override
    public List<InformedConsentDoc> extract(MedrecVo medrecVo) {
        List<InformedConsentDoc> retList = Lists.newArrayList();
        Map<String, List<String>> contentMap = (Map) medrecVo.getContent().get("content");
        if (contentMap == null) {
            return retList;
        }
        for (Map.Entry<String, List<String>> entry : contentMap.entrySet()) {
            InformedConsentDoc informedConsentDoc = getInformedConsentDoc((List) entry.getValue());
            retList.add(informedConsentDoc);
        }
        return retList;

    }

    private InformedConsentDoc getInformedConsentDoc(List<Map<String, Object>> contentMaps) {
        InformedConsentDoc informedConsentDoc = new InformedConsentDoc();
        if (ListUtil.isEmpty(contentMaps)) {
            return informedConsentDoc;
        }
        for (Map<String, Object> contentMap : contentMaps) {
            if (contentMap.get("xmlText") == null || StringUtil.isBlank(contentMap.get("xmlText").toString())) {
                continue;
            }
            try {
                String content = contentMap.get("xmlText").toString();
                Map<String, String> structureMap = null;
                if (contentMap.get("isParsed") != null && "1".equals(contentMap.get("isParsed").toString())) {
                    structureMap = (Map) FastJsonUtils.getJsonToMap(content);
                } else {
                    String recTitle = contentMap.get("recTitle").toString();
                    String recTypeId = contentMap.get("recTypeId").toString();
                    BeiLunHtmlAnalysis beiLunHtmlAnalysis = new BeiLunInformedHtmlAnalysis();
                    Map<String, String> sourceMap = beiLunHtmlAnalysis.analysis(content, recTitle, recTypeId);
                    if (MapUtils.isNotEmpty(sourceMap)) {
                        structureMap = OrdinaryAssistant.mapKeyContrast(sourceMap, keyContrasts);
                        structureMap.put("记录编号", contentMap.get("recId").toString());
                        structureMap.put("标题", recTitle);
                        structureMap.put("病历号", contentMap.get("behospitalCode") == null ? null : contentMap.get("behospitalCode").toString());
                    }
                }
                if (MapUtils.isNotEmpty(structureMap)) {
                    informedConsentDoc = ModelDocGenerate.informedConsentDocGen(structureMap);
                    informedConsentDoc.setText(CommonAnalysisUtil.html2String(content));
                    informedConsentDoc.setPageData((Map) structureMap);
                }
            } catch (Exception e) {
                log.error(e.getMessage(), e);
            }
        }
        return informedConsentDoc;
    }


    private List<String> keyContrasts = Lists.newArrayList(
            "患者签名=患方签名",
            "患方手写意见=患方签名",
            "患方手写意见患方签名=患方签名",
            "患方或受托代理人签名=患方或受托代理人签名",
            "代理人签名=被授权人签名",
            "被授权人签名=被授权人签名"
    );
}
