package com.lantone.qc.trans.ningbozhenhai.util;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.lantone.qc.pub.util.StringUtil;
import com.lantone.qc.trans.comsis.CommonAnalysisUtil;
import lombok.extern.slf4j.Slf4j;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;

import java.util.List;
import java.util.Map;

/**
 * @Description: 病危（重）通知单html解析
 * @author: HUJING
 * @time: 2020/9/14 15:28
 */
@Slf4j
public class CriticallyIllNoticeHtmlAnalysis implements HtmlAnalysis {

    private String modeId = "25";

    @Override
    public Map<String, String> analysis(String... args) {
        Map<String, String> structureMap = Maps.newLinkedHashMap();

        try {
            List<String> titles = Lists.newArrayList("姓名", "科别", "床号", "病案号",
                    "1.简要病情", "2.目前诊断", "3.目前病情评估", "4.目前患者病情危重，随时出现以下一种或多种危及患者生命的并发症，且病情有进一步恶化\n" +
                            "可能", "5.注意事项", "谈话医师签名", "签名日期", "时间", "6.患方知情选择",
                    "患者签名", "指印", "患者签名时间", "若患者无法签署知情同意书或授权于亲属，请法定监护人或被授权人在此签名", "法定监护人/被授权人签名", "与患者关系", "法定监护人签名时间");
            String html = args[0];
            String recTitle = args[1];
            String recTypeId = args[2];
            Document doc = Jsoup.parse(html);
            String htmlContent = HtmlAnalysisUtil.blockDivToStr(doc.selectFirst("body").child(0), true)
                    .replace("患者签名", "患者签名：")
                    .replace("法定监护人/被授权人签名", "法定监护人/被授权人签名：")
                    .replace("与患者关系", "与患者关系：")
                    .replace("指印", "指印：")
                    .replace("第1页", "");

            int index1 = htmlContent.indexOf("患者签名");
            int index2 = htmlContent.lastIndexOf("法定监护人/被授权人签名");
            if (index1 != -1 && index2 != -1) {
                htmlContent = htmlContent.substring(0, index1)
                        + htmlContent.substring(index1, index2).replace("签名时间", "患者签名时间").replace("年    月    日    时    分", "")
                        + htmlContent.substring(index2).replace("签名时间", "法定监护人签名时间").replace("年    月    日    时    分", "");
            }

            if (StringUtil.isNotBlank(htmlContent)) {
                htmlContent = htmlContent.replaceAll("[   ]", " ");
                CommonAnalysisUtil.html2StructureMap(titles, htmlContent, structureMap);
            }
            structureMap.put("患者签名", structureMap.get("患者签名").replace("患者签名", ""));
            structureMap.put("法定监护人/被授权人签名", structureMap.get("法定监护人/被授权人签名").replace("患方签名", ""));
            CommonAnalysisUtil.processTypeRight(structureMap, "3.目前病情评估");
            CommonAnalysisUtil.processType(structureMap, "6.患方知情选择");
            CommonAnalysisUtil.processType(structureMap, "指印");
            HtmlAnalysisUtil.insertModuleId(modeId, recTypeId, structureMap);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }
        return structureMap;
    }

}