package com.lantone.qc.trans.ningbozhongyi.util;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.lantone.qc.pub.util.StringUtil;
import com.lantone.qc.trans.comsis.CommonAnalysisUtil;
import lombok.extern.slf4j.Slf4j;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;

import java.util.List;
import java.util.Map;

/**
 * @Description: 死亡记录html解析
 * @author: HUJING
 * @time: 2020/9/14 15:41
 */
@Slf4j
public class NingBoZhongYiDeathRecordHtmlAnalysis implements NingBoZhongYiHtmlAnalysis {

    private String modeId = "24";

    @Override
    public Map<String, String> analysis(String... args) {
        Map<String, String> structureMap = Maps.newLinkedHashMap();
        try {
            List<String> titles = Lists.newArrayList("性别", "年龄", "婚姻", "入院日期", "死亡时间", "入院情况", "入院诊断",
                    "诊疗经过（重点记录病情演变、抢救经过）", "诊疗经过", "死亡原因", "死亡诊断", "医师签字", "医生签名", "记录时间");
            String html = args[0];
            String recTitle = args[1];
            String recTypeId = args[2];
            Document doc = Jsoup.parse(html);
            NingBoZhongYiHtmlAnalysisUtil.tableStyle1InsertMap(doc.getElementById("table1"), structureMap);
            String htmlContent = NingBoZhongYiHtmlAnalysisUtil.blockDivToStr(doc.selectFirst("body").child(0), false);
            if (StringUtil.isNotBlank(htmlContent)) {
                htmlContent = htmlContent.replaceAll("[   ]", " ");
                CommonAnalysisUtil.html2StructureMap(titles, htmlContent, structureMap);
            }
            if (CommonAnalysisUtil.extractDate(structureMap.get("医生签名")) != null) {
                structureMap.put("记录时间", CommonAnalysisUtil.extractDate(structureMap.get("医生签名")));
            }
            structureMap.put("医生签名", structureMap.get("医生签名").replace("时间", ""));
            CommonAnalysisUtil.extractDateByTitle(structureMap, "记录时间");
            NingBoZhongYiHtmlAnalysisUtil.insertModuleId(modeId, recTypeId, structureMap);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }
        return structureMap;
    }
}