package com.lantone.qc.trans.shengzhouyy;

import com.google.common.collect.Lists;
import com.lantone.qc.dbanaly.facade.yiwu.YiWuXmlUtil;
import com.lantone.qc.dbanaly.util.ModuleMappingUtil;
import com.lantone.qc.pub.model.doc.DifficultCaseDiscussDoc;
import com.lantone.qc.pub.model.vo.MedrecVo;
import com.lantone.qc.pub.util.FastJsonUtils;
import com.lantone.qc.trans.ModelDocTrans;
import com.lantone.qc.trans.comsis.CommonAnalysisUtil;
import com.lantone.qc.trans.comsis.OrdinaryAssistant;
import org.apache.commons.lang3.StringUtils;

import java.util.List;
import java.util.Map;

/**
 * @Description: 疑难病例讨论记录文档生成
 */
public class DifficultCaseDiscussDocTrans extends ModelDocTrans {
    private String modeId = "19";

    @Override
    public List<DifficultCaseDiscussDoc> extract(MedrecVo medrecVo) {
        List<DifficultCaseDiscussDoc> retList = Lists.newArrayList();
        List<Map<String, Object>> contentMaps = (List) medrecVo.getContent().get("content");
        contentMaps.forEach(contentMap -> {
            retList.add(getDifficultCaseDiscussDoc(contentMap));
        });
        return retList;
    }

    private DifficultCaseDiscussDoc getDifficultCaseDiscussDoc(Map<String, Object> contentMap) {
        String content = contentMap.get("xmlText").toString();
        Map<String, String> structureMap = null;
        if (contentMap.get("isParsed") != null && "1".equals(contentMap.get("isParsed").toString())) {
            structureMap = (Map) FastJsonUtils.getJsonToMap(content);
        } else {
            Map<String, String> sourceMap = YiWuXmlUtil.xmlToMap(content);
            List<String> titles = Lists.newArrayList("讨论日期", "讨论意见", "地点", "主持人", "参加人员的姓名及专业技术职务", "主持人小结",
                    "记录医师", "记录医师签名", "主持人签名", "汇报病情", "讨论目的", "讨论时间","参加人员","入院诊断",
                    "讨论摘要","讨论内容");
            String text = sourceMap.get("原始文本");
            List<String> sortTitles = CommonAnalysisUtil.sortTitles(titles, text);
            CommonAnalysisUtil.cutByTitles(text, sortTitles, 0, sourceMap);
            sourceMap.put("mode_id", ModuleMappingUtil.getDeptModuleId(modeId));
            sourceMap.put("mode_id=" + contentMap.get("modeId").toString(), "");
            sourceMap.put("rec_title=" + contentMap.get("recTitle").toString(), "");
            String talk_time = sourceMap.get("讨论时间");
            if (StringUtils.isNotBlank(talk_time)) {
                String[] split = talk_time.split(" ");
                if (split.length > 0) sourceMap.put("讨论时间", split[0]);
            }
            structureMap = OrdinaryAssistant.mapKeyContrast(sourceMap, keyContrasts, modeId);
        }

        DifficultCaseDiscussDoc difficultCaseDiscussDoc = new DifficultCaseDiscussDoc();
        difficultCaseDiscussDoc.setStructureMap(structureMap);
        difficultCaseDiscussDoc.setPageData((Map) structureMap);

        return difficultCaseDiscussDoc;
    }

    private List<String> keyContrasts = Lists.newArrayList(
            /*"医生=记录者",
            "讨论小结=主持人小结",
            "讨论意见=具体讨论意见",
            "讨论日期时间=讨论日期",
            "本人姓名=姓名",
            "参加人员及职称（护士）=参加人员的姓名及专业技术职务",
            "患者姓名=姓名",
            "性别代码=性别",
            "年龄 (岁)=年龄",
            "当前科室=科别",
            "主持人姓名=主持人姓名及专业技术职务",
            "参加讨论人员名单=参加人员的姓名及专业技术职务",
            "讨论内容=具体讨论意见",
            "讨论时间=讨论日期"*/
            "病程时间=记录时间",
            "地点=讨论地点",
            "主持人=主持人姓名及专业技术职务",
            "主持人小结=主持人总结",
            "汇报病情=汇报病史",
            "讨论意见=讨论发言",
            "记录医师签名=记录医生",
            "入院诊断=汇报病史",
            "参加人员=参加人员的姓名及专业技术职务",
            "讨论摘要=讨论发言",
            "讨论内容=讨论发言",
            "讨论时间=讨论日期"
    );
}
