package com.lantone.qc.trans.taizhou;

import com.google.common.collect.Lists;
import com.lantone.qc.dbanaly.facade.taizhou.TzXmlUtil;
import com.lantone.qc.pub.model.doc.InvasiveOperationDoc;
import com.lantone.qc.pub.model.vo.MedrecVo;
import com.lantone.qc.pub.util.FastJsonUtils;
import com.lantone.qc.trans.ModelDocTrans;
import com.lantone.qc.trans.comsis.OrdinaryAssistant;
import org.apache.commons.lang3.StringUtils;
import java.util.List;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @Description: 有创操作记录文档生成
 * @author: rengb
 * @time: 2020/3/17 13:27
 */
public class TaiZhouInvasiveOperationDocTrans extends ModelDocTrans {
    private String modeId = "59";

    @Override
    public List<InvasiveOperationDoc> extract(MedrecVo medrecVo) {
        List<InvasiveOperationDoc> retList = Lists.newArrayList();
        List<Map<String, Object>> contentMaps = (List) medrecVo.getContent().get("content");
        contentMaps.forEach(contentMap -> {
            retList.add(getInvasiveOperationDoc(contentMap));
        });
        return retList;
    }

    private InvasiveOperationDoc getInvasiveOperationDoc(Map<String, Object> contentMap) {
        String content = contentMap.get("xmlText").toString();
        Map<String, String> structureMap = null;
        if (contentMap.get("isParsed") != null && "1".equals(contentMap.get("isParsed").toString())) {
            structureMap = (Map) FastJsonUtils.getJsonToMap(content);
        } else {
            Map<String, String> xmlNodeValueMap = TzXmlUtil.getXmlToMapForTZ(content);
            xmlNodeValueMap.put("mode_id=" + contentMap.get("modeId").toString(), "");
            xmlNodeValueMap.put("rec_title=" + contentMap.get("recTitle").toString(), "");
            structureMap = OrdinaryAssistant.mapKeyContrast(xmlNodeValueMap, keyContrasts, modeId);
        }
        preSolve(contentMap.get("contentText").toString(),structureMap);
        InvasiveOperationDoc invasiveOperationDoc = new InvasiveOperationDoc();
        invasiveOperationDoc.setStructureMap(structureMap);
        invasiveOperationDoc.setPageData((Map) structureMap);

        return invasiveOperationDoc;
    }
    Map<String, String>preSolve(String content,Map<String, String>structureMap){
        String rex = "[\\s\\S]*[(?=无)|(?=有)][^,;，；。]{0,3}(?=不适)[\\s\\S]*";
            Pattern p = Pattern.compile(rex);
            Matcher m = p.matcher(content);
            String result = "";
            while (m.find()) {
                result = m.group().trim();
            }
      if(StringUtils.isNotBlank(result)){
          structureMap.put("有无记录不良反应","true");
      }else{
          structureMap.put("有无记录不良反应","false");
      }
        if(structureMap.containsKey("术后注意") && structureMap.get("术后注意").matches(rex)){
            structureMap.put("有无记录不良反应","false");
        }

        if(structureMap.containsKey("术前准备") && null != structureMap.get("术前准备")){
            String str = structureMap.get("术前准备");
            structureMap.put("术前准备",getKeyCut(str));
        }
        return structureMap;
    };

    String getKeyCut(String key){
        for (String str : keyCut) {
            if(key.contains(str)){
                key = key.substring(0, key.indexOf(str));
            }
        }
        return key;
    }
//"术前准备" -> "操作前检查穿刺部位皮肤完整无破损。核对病人（Time Out）：姓名、出生日期、住院号、穿刺部位。核对后签名："
    private List<String> keyContrasts = Lists.newArrayList(
            "本人姓名=姓名",
            "入院日期=入院时间",
            "操作项目=操作名称",
            "临床科室=科别",
            "出院时情况=出院情况",
            "事件日期=操作日期",
            "操作前准备=术前准备",
            "操作过程=操作步骤",
            "病历号=病案号",
            "患者一般情况=一般情况",
            "注意事项=术后注意",
            "医生=操作医师签名"
    );

    private List<String> keyCut =    Lists.newArrayList(
                    "核对病人（Time Out）",
                             "核对后签名"
            );
}