package com.lantone.qc.trans.wenfuyi;

import com.google.common.collect.Lists;
import com.lantone.qc.pub.model.doc.BeHospitalizedDoc;
import com.lantone.qc.pub.model.vo.MedrecVo;
import com.lantone.qc.pub.util.FastJsonUtils;
import com.lantone.qc.trans.ModelDocTrans;
import com.lantone.qc.trans.comsis.ModelDocGenerate;
import com.lantone.qc.trans.comsis.OrdinaryAssistant;
import com.lantone.qc.trans.wenfuyi.util.BeHospitalizedHtmlAnalysis;
import com.lantone.qc.trans.wenfuyi.util.WenFuYiHtmlAnalysis;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.MapUtils;

import java.util.List;
import java.util.Map;

/**
 * @Description: 入院记录文档生成
 * @author: rengb
 * @time: 2020/3/5 15:47
 */
@Slf4j
public class BeHospitalizedDocTrans extends ModelDocTrans {

    @Override
    public BeHospitalizedDoc extract(MedrecVo medrecVo) {
        BeHospitalizedDoc beHospitalizedDoc = null;
        try {
            /*Map<String, Object> contentMap = ((List<Map>) medrecVo.getContent().get("content")).get(0);
            String content = contentMap.get("htmlText").toString();*/
            List<Map> map = (List<Map>) medrecVo.getContent().get("content");
            StringBuffer sb = new StringBuffer();
            Map<String, Object> contentMap = null;
            if (map.size() > 1) {
                for (Map<String, Object> a : map) {
                    sb.append(a.get("htmlText"));
                    if (a.get("recTitle").toString().contains("（一）") || a.get("recTitle").toString().contains("(一)")) {
                        contentMap = a;
                    }
                }
            } else {
                contentMap = ((List<Map>) medrecVo.getContent().get("content")).get(0);
            }
            String content = sb.toString();
            Map<String, String> structureMap = null;
            if (map.get(0).get("isParsed") != null && "1".equals(map.get(0).get("isParsed").toString())) {
                structureMap = (Map) FastJsonUtils.getJsonToMap(content);
            } else {
                String recTitle = contentMap.get("recTitle").toString();
                String recTypeId = contentMap.get("recTypeId").toString();
                WenFuYiHtmlAnalysis wenFuYiHtmlAnalysis = new BeHospitalizedHtmlAnalysis();
                Map<String, String> sourceMap = wenFuYiHtmlAnalysis.analysis(content, recTitle, recTypeId);
                if (MapUtils.isNotEmpty(sourceMap)) {
                    structureMap = OrdinaryAssistant.mapKeyContrast(sourceMap, keyContrasts);
                    structureMap.put("记录编号", contentMap.get("recId").toString());
                    structureMap.put("病历号", contentMap.get("behospitalCode") == null ? null : contentMap.get("behospitalCode").toString());
                }
            }
            if (MapUtils.isNotEmpty(structureMap)) {
                beHospitalizedDoc = ModelDocGenerate.beHospitalizedDocGen(structureMap);
                beHospitalizedDoc.setPageData((Map) structureMap);
            }
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }
        return beHospitalizedDoc;
    }

    private List<String> keyContrasts = Lists.newArrayList(
            "单位=工作单位",
            "过去史=既往史",
            "户口地址=籍贯"

    );

}