package com.lantone.qc.trans.wenfuyi.util;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.lantone.qc.pub.util.StringUtil;
import com.lantone.qc.trans.comsis.CommonAnalysisUtil;
import lombok.extern.slf4j.Slf4j;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;

import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @author: rengb
 * @time: 2020/9/15 16:28
 */
@Slf4j
public class BeHospitalizedHtmlAnalysis implements WenFuYiHtmlAnalysis {

    private String modeId = "1";

    @Override
    public Map<String, String> analysis(String... args) {
        Map<String, String> map = Maps.newLinkedHashMap();
        try {
            String html = args[0];
            String recTitle = args[1];
            String recTypeId = args[2];
            Document doc = Jsoup.parse(html);

            if (recTitle.contains("24")) {
                analysis24h(doc, map);
            } else if (recTitle.contains("日间病历")) {
                analysisDay(doc, map);
            } else {
                analysisGeneral(doc, recTitle, map);
            }
            WenFuYiHtmlAnalysisUtil.insertModuleId(modeId, recTypeId, map);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }
        return map;
    }

    //一般模板
    private void analysisGeneral(Document doc, String recTitle, Map<String, String> map) {

        String htmlContent = WenFuYiHtmlAnalysisUtil.blockDivToStr(doc.selectFirst("body"), true)
                .replace("注意：询问有无境外和国内中高风险疫区居留史和接触史。", "")
                .replace("（拟诊或确诊肿瘤病人应记录转移区域的淋巴结情况、已有区域及淋巴结性质。）", "")
                .replace("（外院检查注明该医院名称、日期、报告编号！）", "")
                .replace("（外院检查注明该医院名称、日期！）", "");

        List<String> titles = Lists.newArrayList("姓 名", "邮 编", "性 别", "单位", "年 龄", "身份证号码", "婚 姻", "户口地址", "民 族", "联系电话", "出生地",
                "入院日期", "职 业", "病史陈述者", "主诉", "现病史", "过去史", "既往史", "系统回顾", "个人史", "婚育史", "家族史", "一般情况", "特殊检查", "实验室检查", "初步诊断", "修正诊断");

        titles = CommonAnalysisUtil.sortTitles(titles, htmlContent);
        CommonAnalysisUtil.cutByTitles(htmlContent, titles, 0, map);
        if (map.get("初步诊断").contains("医师签名")) {
            map.put("初步诊断医师签名", map.get("初步诊断").substring(map.get("初步诊断").indexOf("医师签名") + 5));
            map.put("初步诊断", map.get("初步诊断").substring(0, map.get("初步诊断").indexOf("医师签名")));
            if (map.get("初步诊断医师签名").contains("日期")) {
                map.put("初步诊断日期", map.get("初步诊断医师签名").substring(map.get("初步诊断医师签名").indexOf("日期") + 3));
                map.put("初步诊断医师签名", map.get("初步诊断医师签名").substring(0, map.get("初步诊断医师签名").indexOf("日期")).replace("医师签名： ", ""));
            }
        }
        if (map.get("修正诊断").contains("医师签名")) {
            map.put("修正诊断医师签名", map.get("修正诊断").substring(map.get("修正诊断").indexOf("医师签名") + 5));
            map.put("修正诊断", map.get("修正诊断").substring(0, map.get("修正诊断").indexOf("医师签名")));
            if (map.get("修正诊断医师签名").contains("日期")) {
                map.put("修正诊断日期", map.get("修正诊断医师签名").substring(map.get("修正诊断医师签名").indexOf("日期") + 3));
                map.put("修正诊断医师签名", map.get("修正诊断医师签名").substring(0, map.get("修正诊断医师签名").indexOf("日期")));
            }
        }

        map.put("辅助检查", "特殊检查：" + map.get("特殊检查") + "；实验室检查：" + map.get("实验室检查"));

    }

    //24小时出入院记录、24小时出入院记录（全院）、24小时入出院记录(全院通用)、24小时内入院死亡记录(全院通用)
    private void analysis24h(Document doc, Map<String, String> map) {
        String text = WenFuYiHtmlAnalysisUtil.blockDivToStr(doc.selectFirst("body").child(0), false);
        text = text.substring(text.lastIndexOf("24小时入出院记录姓    名")).replaceFirst("第1页", "");
        List<String> titles = Lists.newArrayList("姓    名", "家庭住址", "性    别", "工作单位", "年    龄", "身份证号码", "民    族",
                "联系人(关系)", "职    业", "入院时间", "婚    姻", "死亡时间", "记录时间", "出 生 地", "病史陈述者", "主    诉", "入院情况", "心理评估",
                "疼痛评估", "营养评估", "功能评估", "入院诊断", "诊疗经过", "死亡原因", "死亡诊断", "出院情况", "出院诊断", "出院计划", "出院医嘱",
                "出院去向", "医师签名", "书写时间");

        CommonAnalysisUtil.cutByTitles(text, titles, 0, map);
        CommonAnalysisUtil.processType(map, "出院去向");
    }

    //原-日间病历入出院记录、日间病历-性早熟
    private void analysisDay(Document doc, Map<String, String> map) {
        //个人基础信息table解析
        WenFuYiHtmlAnalysisUtil.tableStyle1InsertMap(doc.getElementById("table1"), map);
        //主诉、入院情况等table解析
        WenFuYiHtmlAnalysisUtil.tableStyle2InsertMap(doc.getElementById("table6"), map);
        //医生签名、医生签名时间
        Element docSignElement = null, docSignTimeElement = null;
        for (Element table6ElementNt : doc.getElementById("table6").parent().nextElementSiblings()) {
            docSignElement = table6ElementNt.selectFirst("image,img");
            if (docSignElement != null) {
                docSignTimeElement = table6ElementNt.nextElementSibling();
                break;
            }
        }
        if (docSignElement != null) {
//            map.put("医生签名", docSignElement.outerHtml());
            map.put("医生签名", "暂无");
        }
        if (docSignTimeElement != null) {
            map.put("医生签名时间", WenFuYiHtmlAnalysisUtil.elementLayer1ToStr(docSignTimeElement, false).trim());
        }
    }

    private void disHandleExt(Map<String, String> map) {
        String[] keys = {"中医诊断", "西医诊断"};
        String value = null;
        int index = 0;
        for (String key : keys) {
            value = map.get(key);
            if (StringUtil.isNotBlank(value)) {
                for (String key_ : keys) {
                    index = value.indexOf(key_);
                    if (index > 0) {
                        map.put(key_, value.substring(index + 5));
                        map.put(key, value.substring(0, index));
                    }
                }
            }
        }
    }

}