package com.lantone.qc.trans.wenfuyi.util;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.lantone.qc.pub.util.StringUtil;
import com.lantone.qc.trans.comsis.CommonAnalysisUtil;
import lombok.extern.slf4j.Slf4j;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.nodes.Node;
import org.jsoup.select.Elements;

import java.util.List;
import java.util.Map;

import static com.lantone.qc.trans.comsis.CommonAnalysisUtil.extractDate;

/**
 * @Description: 自定义病程记录html解析
 * @author: HUJING
 * @time: 2020/9/15 10:28
 */
@Slf4j
public class ThreeLevelWardHtmlAnalysis implements WenFuYiHtmlAnalysis {

    private String modeId = "4";

    @Override
    public Map<String, String> analysis(String... args) {
        Map<String, String> structureMap = Maps.newLinkedHashMap();
        try {
            String html = args[0];
            String recTitle = args[1];
            String recTypeId = args[2];
            Document doc = Jsoup.parse(html);
            Element bigDivElement = doc.selectFirst("body");
            if (bigDivElement.childNodeSize() == 1) {
                bigDivElement = bigDivElement.child(0);
            }
            String htmlText = WenFuYiHtmlAnalysisUtil.blockDivToStr(bigDivElement, true);
            CommonAnalysisUtil.extractWardInfo(recTitle, htmlText, structureMap);
            List<String> titles = Lists.newArrayList("摘要", "病程录内容");
            titles = CommonAnalysisUtil.sortTitles(titles, htmlText);
            CommonAnalysisUtil.cutByTitles(htmlText, titles, 0, structureMap);
            WenFuYiHtmlAnalysisUtil.insertModuleId(modeId, recTypeId, structureMap);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }
        return structureMap;
    }

    /**
     * 将html内容以行为单位存进list,从<hr>之后开始处理
     *
     * @param html 原始html内容
     * @return
     */
    public static List<String> html2List(String html, boolean existHr) {
        List<String> htmlText = Lists.newArrayList();
        Document document = Jsoup.parse(html);
        Element body = document.select("body").first();
        List<Node> nodes = body.childNodes();
        List<Node> subNodes = nodes.get(0).childNodes();
        boolean findNode = false;
        for (Node node : subNodes) {
            if ("hr".equals(node.nodeName())) {
                findNode = true;
                continue;
            }
            if (findNode || !existHr) {
                String title = node.attr("title");
                if ("main".equals(title)) {
                    Element element = (Element) node;
                    Elements elements = element.select("div");
                    for (Element e : elements) {
                        String text = e.text();
                        if (text.length() > 150) {
                            continue;
                        }
                        htmlText.add(text);
                    }
                }
            }
        }
        if (htmlText.get(0).length() > 200) {
            htmlText.remove(0);
        }
        return htmlText;
    }

}